bayespy.inference.vmp.nodes.gaussian.GaussianGammaISOMoments.add_converter
==========================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaISOMoments.add_converter